/* General Reset */
* {
    margin: 0;
    padding: 0;
    box-sizing: border-box;
}

body {
    font-family: 'Courier New', Courier, monospace;
    background-color: #2b2b2b;
    color: #eaeaea;
    min-height: 100vh;
}

.container {
    display: flex;
    flex-direction: column;
    width: 100vw;
    height: 100vh;
    background-color: #1e1e1e;
    border: 2px solid #444;
    box-shadow: 0 4px 10px rgba(0, 0, 0, 0.5);
}

.header {
    width: 100%;
    padding: 16px;
    text-align: center;
    font-size: 1.5rem;
    background-color: #3c3c3c;
    color: #fff;
    height: 7%;
    border-bottom: 2px solid #444;
}

.ide {
    display: flex;
    flex-direction: column;
    gap: 8px;
    background-color: #2e2e2e;
    border: 2px solid #444;
    padding: 16px;
    height: 53%;
}

.ide .editor {
    flex: 1;
    background-color: #1e1e1e;
    border: 1px solid #555;
    color: #eaeaea;
    font-family: 'Courier New', Courier, monospace;
    overflow: auto;
    padding: 8px;
    line-height: 1.5;
}

.ide .editor {
    float: left;
    text-align: right;
    padding-right: 8px;
    margin-right: 8px;
    color: #888;
}

.ide .dropdown {
    display: flex;
    justify-content: space-between;
    align-items: center;
    gap: 16px;
}

.dropdown select {
    padding: 4px;
    background-color: #3c3c3c;
    color: #fff;
    border: 1px solid #555;
    font-family: 'Courier New', Courier, monospace;
    cursor: pointer;
}

.button {
    display: inline-block;
    padding: 8px 16px;
    background-color: #ffcc00;
    color: #252525;
    text-align: center;
    border: none;
    font-weight: bold;
    cursor: pointer;
    transition: background-color 0.3s;
}

.button:hover {
    background-color: #e6b800;
}

.repl {
    margin-top: 16px;
    background-color: #2e2e2e;
    border: 2px solid #444;
    padding: 16px;
    height: 40%;
    width: 100%;
    overflow: auto;
    font-family: 'Courier New', Courier, monospace;
    color: #eaeaea;
}

.repl .output {
    white-space: pre-wrap;
    color: #8fc229;
}

#code-area {
    font-family: 'Courier New', Courier, monospace;
    color: white;
    width: 100%;
    height: 100%;
    background: transparent;
    resize: none;
    border: 0;
    outline: none;
}

.checkbox {
    transform: scale(2);
}

#mode-select {
    margin-right: 67%;
}

.help-button {
    position: absolute;
    top: 16px;
    right: 16px;
    background-color: #ffcc00;
    color: #252525;
    padding: 8px 16px;
    height: 40px;
    width: 40px;
    border-radius: 40px;
    cursor: pointer;
    transition: background-color 0.3s;
    text-align: center;
    display: flex;
    justify-content: center;
    align-items: center;
    font-size: 24px;
    font-weight: bold;
    text-transform: uppercase;
    letter-spacing: 0.1em;
}

.help-button:hover {
    background-color: #e6b800;
}

#help-modal {
    text-align: left;
    position: fixed;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    background-color: #2e2e2e;
    color: #eaeaea;
    padding: 20px;
    border-radius: 8px;
    box-shadow: 0 4px 20px rgba(0, 0, 0, 0.5);
    max-width: 600px;
    width: 90%;
    z-index: 1000;
    overflow-y: auto;
    max-height: 80vh;
}

.help-modal h2,
.help-modal h3 {
    color: #ffcc00;
}

.help-modal h3 {
    margin-top: 16px;
}

.help-modal ul {
    list-style-type: disc;
    margin-left: 20px;
}

.help-modal pre {
    background-color: #1e1e1e;
    padding: 10px;
    border-radius: 4px;
    overflow-x: auto;
}
